pub struct RenderPassDepth<'pass> {
pub texture: Option<&'pass TextureView>,
pub load: LoadOp<f32>,
pub store: StoreOp,
}Expand description
Describe the optional depth attachment of a render pass.
Fields
texture: Option<&'pass TextureView>The depth texture. If None, the render pass will not have a depth texture.
load: LoadOp<f32>The depth operation when loading the texture. By default, load the existing texture.
store: StoreOpThe depth operation when storing the texture. By default, store the texture.